# Installing the required packages for this analysis and the other tutorials. 
# This is only required once. 
# install.packages(c("eRm", "dplyr", "ggplot2", "pairwise", "TAM", "psych"))

# Load the packages required for the analysis
library(eRm)
library(dplyr)

# Reading in the comma-seperated data set
df <- read.csv("BLOT.csv", header = FALSE, sep = ";") 

# Look at the dimensions of "df" - we have 150 rows and 49 columns
dim(df)
# Defining the name of the first column of the data frame called "df"
colnames(df)[1] <- c("id") 
# Defining the names of the columns referring to the items
colnames(df)[2:49] <- paste("Blot", (1:48), sep="_") 
# Selecting only the BLOT items
blot_items <- dplyr::select(df, Blot_1:Blot_35) 
# Looking at the first five rows of the dataframe
head(blot_items)

# Estimates Rasch model parameters
fit_rasch_blot <- eRm::RM(blot_items) 

# Look at the documentation for the RM function
?RM

# Estimating person parameters for each observed raw score. 
pparameters_blot <- eRm::person.parameter(fit_rasch_blot) 

# Estimate item parameters
item_fit <- eRm::itemfit(pparameters_blot) 
print(item_fit)

print(item_fit, sort_by = "infit_t")

print(item_fit, sort_by = "infit_t", decreasing = TRUE)

print(item_fit, sort_by = "infit_MSQ", decreasing = TRUE)

print(item_fit, sort_by = "outfit_t")      

print(item_fit, sort_by = "outfit_MSQ", decreasing = TRUE)

print(item_fit, sort_by = "p", digits = 2)

print(item_fit, sort_by = "p", decreasing = TRUE)

print(item_fit, sort_by = "discrim")      

# Displaying item parameters, their standard errors and their 95% confidence intervals
summary(fit_rasch_blot)

# Person separation reliability, total person variance, 
# and model error variance
summary(SepRel(pparameters_blot))

# Wright map
plotPImap(fit_rasch_blot, irug = TRUE, sort = TRUE) 

# Pathway map with
# 95% confidence intervals for the item parameters
plotPWmap(fit_rasch_blot, itemCI = list()) 

# Expected Score ICCs – items # 6, 4, 21
plotjointICC(fit_rasch_blot, item.subset = c("Blot_4", "Blot_6", "Blot_21"))


# Expected Score ICCs – items # 6, 4, 21
plotjointICC(fit_rasch_blot, item.subset = c("Blot_4", "Blot_6", "Blot_21"))

# Indicate an inflection point & location of item 4's difficulty
arrows(x0=0, x1=0, y0=0, y1=.5)


# Actual vs theoretical ICC:
plotICC(fit_rasch_blot, item.subset = c("Blot_21"), empICC = list("raw", type = "b", col = "blue", lty = "dotted"), xlim = c(-4,8)) 

# Actual vs theoretical ICC, with 95% confidence intervals:
plotICC(fit_rasch_blot, item.subset = c("Blot_21"), empICC = list("raw"), empCI = list(), xlim = c(-4,8))
